faker\_file.contrib package
===========================

Subpackages
-----------

.. toctree::
   :maxdepth: 20

   faker_file.contrib.pdf_file

Submodules
----------

faker\_file.contrib.docx\_file module
-------------------------------------

.. automodule:: faker_file.contrib.docx_file
   :members:
   :undoc-members:
   :show-inheritance:

faker\_file.contrib.odt\_file module
------------------------------------

.. automodule:: faker_file.contrib.odt_file
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: faker_file.contrib
   :members:
   :undoc-members:
   :show-inheritance:
